==> hermes-5.3.0.19.tar.gz: hermes-5.3.0.19/spec/factories/housing_requests_factory.rb <==
require 'faker'

FactoryBot.define do
  factory :housing_request, class: Hermes::HousingRequest do
    seeked_departments {['75']}
    trait :with_dependents do
      transient do
        dependents do
          [{
            "last_name" => "GOUBILL",
            "first_name" => "CHRIS",
            "birth_date" => "2017-03-23T00:00:00.000Z",
            "rel_type" => "E",
            "coparentality" => "G",
            "sex" => "M"
          },
          {
            "last_name" => "GOUBILL",
            "first_name" => "CHRIsdS",
            "birth_date" => "1990-03-23T00:00:00.000Z",
            "rel_type" => "E",
            "coparentality" => "G",
            "sex" => "M"
          },
          {
            "last_name" => "GOUBILLze",
            "first_name" => "CHRIS",
            "birth_date" => "2017-03-23T00:00:00.000Z",
            "rel_type" => "P",
            "sex" => "M"
          }]
        end
      end

      after :build do |req, evaluator|
        req.dependents = evaluator.dependents
      end
    end

    after :build do |req, evaluator|
      Hermes::HousingChannel.find_or_create_by key: 'dc' 
    end
  end

  factory :active_request, parent: :housing_request do
    is_active { true }
    association :main_applicant, factory: :applicant

    trait :with_applicants do
      transient do
        applicants_count { 3 }
      end
      after :build do |req, evaluator|
        evaluator.applicants_count.times { req.applicant_ids << create(:applicant).id }
      end
    end
  end

  factory :complete_housing_request, parent: :active_request do

    after :create do |housing_request, evaluator|
      create(:nud, housing_request: housing_request, department: nil, creation_date: DateTime.now, unique_number: housing_request.id.to_s[-14..-1])
      housing_request.validate_all_required_document
    end
  end

  factory :sne_integrate_request, parent: :housing_request do
    is_active { true }
    is_sne_update_available { true }

    transient do
      xml_file_path { [Hermes::Engine.root, %w[spec xml_bouchon DEM_0130620003912G1U05.xml]].flatten.join('/') }
      main_applicant { create(:applicant, first_name: 'Tom', last_name: 'PLATO', birth_date: '1989-01-01') }
    end

    before :create do |housing_request, evaluator|
      main_applicant = evaluator.main_applicant
      housing_request.main_applicant = main_applicant
    end

    after :create do |housing_request, evaluator|
      file = File.open(evaluator.xml_file_path)
      doc = Nokogiri::XML(file)
      file.close
      housing_request.create_xml_model(doc.to_xml)
      parsed = housing_request.parse_xml(housing_request.xml.xml)
      num = parsed['interfaceNuu']['demande']['demandeLogement']['numUnique']
      date = parsed['interfaceNuu']['demande']['demandeLogement']['dateCreationDemande']
      create(:nud, housing_request: housing_request, department: nil, creation_date: date, unique_number: num)
    end
  end
end

==> hermes-5.3.0.34.tar.gz: hermes-5.3.0.34/spec/factories/housing_requests_factory.rb <==
require 'faker'

FactoryBot.define do
  factory :housing_request, class: Hermes::HousingRequest do
    trait :with_dependents do
      transient do
        dependents do
          [{
            "last_name" => "GOUBILL",
            "first_name" => "CHRIS",
            "birth_date" => "2017-03-23T00:00:00.000Z",
            "rel_type" => "E",
            "coparentality" => "G",
            "sex" => "M"
          },
          {
            "last_name" => "GOUBILL",
            "first_name" => "CHRIsdS",
            "birth_date" => "1990-03-23T00:00:00.000Z",
            "rel_type" => "E",
            "coparentality" => "G",
            "sex" => "M"
          },
          {
            "last_name" => "GOUBILLze",
            "first_name" => "CHRIS",
            "birth_date" => "2017-03-23T00:00:00.000Z",
            "rel_type" => "P",
            "sex" => "M"
          }]
        end
      end

      after :build do |req, evaluator|
        req.dependents = evaluator.dependents
      end
    end

    after :build do |req, evaluator|
      Hermes::HousingChannel.find_or_create_by key: 'dc' 
    end
  end

  factory :active_request, parent: :housing_request do
    is_active { true }
    association :main_applicant, factory: :applicant, salary: 2000

    trait :with_applicants do
      transient do
        applicants_count { 3 }
      end
      after :build do |req, evaluator|
        evaluator.applicants_count.times { req.applicant_ids << create(:applicant).id }
      end
    end
  end

  factory :complete_request, parent: :housing_request do
    is_active { true }
    widen_request { true}
    seeked_departments { ['34']}
    association :main_applicant, factory: :applicant, salary: 2000

    after :create do  |hr, evaluator|
      nud = hr.unique_numbers.present? ? hr.unique_numbers.last :  hr.id.to_s[-14..-1]
      Hermes::Nud.create(unique_number: nud, housing_request: hr)
      hr.validate_all_required_document
    end 
  end 

  factory :sne_integrate_request, parent: :housing_request do
    is_active { true }
    is_sne_update_available { true }

    transient do
      xml_file_path { [Hermes::Engine.root, %w[spec xml_bouchon DEM_0130620003912G1U05.xml]].flatten.join('/') }
      main_applicant { create(:applicant, first_name: 'Tom', last_name: 'PLATO', birth_date: '1989-01-01') }
    end

    before :create do |housing_request, evaluator|
      main_applicant = evaluator.main_applicant
      housing_request.main_applicant = main_applicant
    end

    after :create do |housing_request, evaluator|
      file = File.open(evaluator.xml_file_path)
      doc = Nokogiri::XML(file)
      file.close
      housing_request.create_xml_model(doc.to_xml)
      parsed = housing_request.parse_xml(housing_request.xml.xml)
      num = parsed['interfaceNuu']['demande']['demandeLogement']['numUnique']
      date = parsed['interfaceNuu']['demande']['demandeLogement']['dateCreationDemande']
      create(:nud, housing_request: housing_request, department: nil, creation_date: date, unique_number: num)
    end
  end
end
